@@ -3,7 +3,7 @@
     stop("need 'amt' aesthetic")
   } else if (!any(names(data) == "x") && any(names(data) == "time")) {
     data$x <- data$time
-  } else {
+  } else if (!any(names(data) == "x")) {
     stop("need 'x' aesthetic")
   }
   ret <- data[!is.na(data$amt), c("x", "amt")]
@@ -73,7 +73,7 @@ StatAmt <- ggplot2::ggproto("StatAmt", ggplot2::Stat,
 #'
 #' ## bid for 5 days followed by qd for 5 days
 #'
-#' et <- seq(bid,qd) %>% et(seq(0,11*24,length.out=100));
+#' et <- seq(bid,qd) %>% et(seq(0,11*24,length.out=100))
 #'
 #' bidQd <- rxSolve(mod1, et, addDosing=TRUE)
 #'
@@ -82,7 +82,7 @@ StatAmt <- ggplot2::ggproto("StatAmt", ggplot2::Stat,
 #'
 #' # of course you can make it a bit more visible
 #'
-#' plot(bidQd, C2) + geom_amt(aes(amt=amt), col="red", lty=1, size=1.2)
+#' plot(bidQd, C2) + geom_amt(aes(amt=amt), col="red", lty=1, linewidth=1.2)
 #' }
 #' @export
 #' @inheritParams ggplot2::stat_identity
