@@ -14,7 +14,7 @@
 }
 
 .isWritable <- function(path) {
-  if (checkmate::checkString(path, len=1)) {
+  if (checkmate::checkString(path, length=1)) {
     if (file.exists(path)) {
       return(file.access(path, mode = 2)[[1]] == 0)
     }
@@ -187,7 +187,7 @@ rxUse <- function(obj, overwrite = TRUE, compress = "bzip2",
       }
     }
     if (!dir.exists(devtools::package_file("src"))) {
-      dir.create(devtools::package_file("src"), recursive = TRUE)
+      dir.create(devtools::package_file("src"), recursive = TRUE, showWarnings = FALSE)
     }
     .pkg <- basename(usethis::proj_get())
     .rx <- loadNamespace("rxode2")
