@@ -1,8 +1,8 @@
 rxTest({
   skip_if_not_installed("units")
 
-  inf.dat <- structure(list(
-    time = structure(c(
+  inf.dat <- data.frame(
+    time = units::set_units(c(
       0, 0.0417, 0.0833, 0.125, 0.1667,
       0.2083, 0.25, 0.2917, 0.3333, 0.375, 0.4167, 0.4583, 0.5, 0.5417,
       0.5833, 0.625, 0.6667, 0.7083, 0.75, 0.7917, 0.8333, 0.875, 0.9167,
@@ -31,10 +31,7 @@ rxTest({
       9.2083, 9.25, 9.2917, 9.3333, 9.375, 9.4167, 9.4583, 9.5, 9.5417,
       9.5833, 9.625, 9.6667, 9.7083, 9.75, 9.7917, 9.8333, 9.875, 9.9167,
       9.9583, 10
-    ), class = "units", units = structure(list(
-      numerator = "d",
-      denominator = character(0)
-    ), class = "symbolic_units")),
+    ), value = "d"),
     intestine = c(
       0, 0.0737, 0.0574, 0.0447, 0.0348, 0.0271,
       0.0211, 0.0165, 0.0128, 0.01, 0.0078, 0.0061, 0.0047, 0.0037,
@@ -66,8 +63,8 @@ rxTest({
       4e-04, 3e-04, 2e-04, 0.0739, 0.0576, 0.0448, 0.0349, 0.0272,
       0.0212, 0.0165, 0.0128, 0.01, 0.0078, 0.0061, 0.0047, 0.0037,
       0.0029, 0.0022, 0.0017, 0.0014, 0.0011, 8e-04, 6e-04, 5e-04,
-      4e-04, 3e-04, 2e-04
-    ), blood = c(
+      4e-04, 3e-04, 2e-04),
+    blood = c(
       0, 0.0095, 0.0254, 0.0373,
       0.0461, 0.0526, 0.0572, 0.0604, 0.0625, 0.0638, 0.0644, 0.0645,
       0.0642, 0.0637, 0.0629, 0.062, 0.0609, 0.0598, 0.0586, 0.0574,
@@ -98,15 +95,11 @@ rxTest({
       0.1248, 0.1218, 0.1189, 0.1161, 0.1133, 0.12, 0.1332, 0.1425,
       0.1488, 0.1527, 0.1549, 0.1557, 0.1554, 0.1544, 0.1528, 0.1507,
       0.1483, 0.1457, 0.1429, 0.14, 0.137, 0.134, 0.131, 0.128,
-      0.125, 0.1221, 0.1192, 0.1163, 0.1135
-    )
-  ), row.names = c(
-    NA,
-    -241L
-  ), class = "data.frame")
+      0.125, 0.1221, 0.1192, 0.1163, 0.1135)
+  )
 
-  inf.dat2 <- structure(list(
-    time = structure(c(
+  inf.dat2 <- data.frame(
+    time = units::set_units(c(
       0, 0.0417, 0.0833, 0.125, 0.1667,
       0.2083, 0.25, 0.2917, 0.3333, 0.375, 0.4167, 0.4583, 0.5, 0.5417,
       0.5833, 0.625, 0.6667, 0.7083, 0.75, 0.7917, 0.8333, 0.875, 0.9167,
@@ -135,10 +128,7 @@ rxTest({
       9.2083, 9.25, 9.2917, 9.3333, 9.375, 9.4167, 9.4583, 9.5, 9.5417,
       9.5833, 9.625, 9.6667, 9.7083, 9.75, 9.7917, 9.8333, 9.875, 9.9167,
       9.9583, 10
-    ), class = "units", units = structure(list(
-      numerator = "d",
-      denominator = character(0)
-    ), class = "symbolic_units")),
+    ), value = "d"),
     intestine = c(
       0, 0.0737, 0.0574, 0.0447, 0.0348, 0.0271,
       0.0211, 0.0165, 0.0128, 0.01, 0.0078, 0.0061, 0.0047, 0.0774,
@@ -162,10 +152,9 @@ rxTest({
       0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
       0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
       0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
-    ), blood = c(
-      0,
-      0.0095, 0.0254, 0.0373, 0.0461, 0.0526, 0.0572, 0.0604, 0.0625,
+      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0),
+    blood = c(
+      0, 0.0095, 0.0254, 0.0373, 0.0461, 0.0526, 0.0572, 0.0604, 0.0625,
       0.0638, 0.0644, 0.0645, 0.0642, 0.0732, 0.0883, 0.0993, 0.1071,
       0.1124, 0.1158, 0.1178, 0.1187, 0.1187, 0.118, 0.1169, 0.1154,
       0.1232, 0.1371, 0.1469, 0.1535, 0.1577, 0.1601, 0.161, 0.1608,
@@ -196,10 +185,10 @@ rxTest({
       0.0184, 0.018, 0.0175, 0.0171, 0.0167, 0.0163, 0.0159, 0.0155,
       0.0151, 0.0147, 0.0144, 0.014, 0.0137, 0.0133, 0.013, 0.0127
     )
-  ), row.names = c(NA, -241L), class = "data.frame")
+  )
 
-  dat3 <- structure(list(
-    time = structure(c(
+  dat3 <- data.frame(
+    time = units::set_units(c(
       0, 0.0417, 0.0833, 0.125, 0.1667,
       0.2083, 0.25, 0.2917, 0.3333, 0.375, 0.4167, 0.4583, 0.5, 0.5417,
       0.5833, 0.625, 0.6667, 0.7083, 0.75, 0.7917, 0.8333, 0.875, 0.9167,
@@ -228,10 +217,7 @@ rxTest({
       9.2083, 9.25, 9.2917, 9.3333, 9.375, 9.4167, 9.4583, 9.5, 9.5417,
       9.5833, 9.625, 9.6667, 9.7083, 9.75, 9.7917, 9.8333, 9.875, 9.9167,
       9.9583, 10
-    ), class = "units", units = structure(list(
-      numerator = "d",
-      denominator = character(0)
-    ), class = "symbolic_units")),
+    ), value = "d"),
     blood = c(
       40, 39.0124, 38.0491, 37.1097, 36.1935, 35.2999,
       34.4283, 33.5783, 32.7492, 31.9406, 31.152, 30.3829, 29.6327,
@@ -269,10 +255,10 @@ rxTest({
       62.3191, 60.7805, 59.2798, 57.8162, 56.3887, 54.9965, 53.6386,
       52.3142, 51.0226, 49.7628, 88.5342
     )
-  ), row.names = c(NA, -241L), class = "data.frame")
+  )
 
-  dat4 <- structure(list(
-    time = structure(c(
+  dat4 <- data.frame(
+    time = units::set_units(c(
       0, 0.0417, 0.0833, 0.125, 0.1667,
       0.2083, 0.25, 0.2917, 0.3333, 0.375, 0.4167, 0.4583, 0.5, 0.5417,
       0.5833, 0.625, 0.6667, 0.7083, 0.75, 0.7917, 0.8333, 0.875, 0.9167,
@@ -301,10 +287,7 @@ rxTest({
       9.2083, 9.25, 9.2917, 9.3333, 9.375, 9.4167, 9.4583, 9.5, 9.5417,
       9.5833, 9.625, 9.6667, 9.7083, 9.75, 9.7917, 9.8333, 9.875, 9.9167,
       9.9583, 10
-    ), class = "units", units = structure(list(
-      numerator = "d",
-      denominator = character(0)
-    ), class = "symbolic_units")),
+    ), value = "d"),
     blood = c(
       40, 39.0124, 38.0491, 37.1097, 36.1935, 35.2999,
       34.4283, 33.5783, 32.7492, 31.9406, 31.152, 30.3829, 69.6327,
@@ -347,7 +330,7 @@ rxTest({
       132.5055, 129.2339, 126.0431, 122.9311, 119.8959, 116.9357,
       114.0486
     )
-  ), row.names = c(NA, -241L), class = "data.frame")
+  )
 
   ## https://cran.r-project.org/web/packages/diffEq/vignettes/ODEinR.pdf p11
 
