@@ -1,17 +1,15 @@
-# Logical expressons test
-
-.rx <- loadNamespace("rxode2")
+# Logical expressions test
 
 transTo <- function(model, syntax, match = TRUE) {
   mod <- rxModelVars(model)
-  
+
   if (match) {
     test_that(sprintf("%s includes %s", model, syntax), {
-      expect_true(regexpr(syntax, .rx$.rxGetParseModel(), fixed = TRUE) != -1)
+      expect_true(regexpr(syntax, .rxGetParseModel(), fixed = TRUE) != -1)
     })
   } else {
     test_that(sprintf("%s dose not include %s", model, syntax), {
-      expect_false(regexpr(syntax, .rx$.rxGetParseModel(), fixed = TRUE) != -1)
+      expect_false(regexpr(syntax, .rxGetParseModel(), fixed = TRUE) != -1)
     })
   }
 }
