@@ -1,6 +1,4 @@
 rxTest({
-  .rx <- loadNamespace("rxode2")
-
   test_that("bounded functions needs numeric bounds", {
     lmat <- lotri({
       tka <- 0.2
@@ -13,14 +11,14 @@ rxTest({
     })
 
     testBounded <- function(type="expit") {
-      expect_error(.rx$.rxMuRef(paste0("a=", type, "(tka + eta.ka, a, b)"), lmat))
-      expect_error(.rx$.rxMuRef(paste0("a=", type, "(tka + eta.ka, 1, b)"), lmat))
-      expect_error(.rx$.rxMuRef(paste0("a=", type, "(tka + eta.ka, 1, b)"), lmat))
-      expect_error(.rx$.rxMuRef(paste0("a=", type, "(tka + eta.ka, 1, 2)"), lmat), NA)
-      expect_error(.rx$.rxMuRef(paste0("a=", type, "(tka + eta.ka, 2, 1)"), lmat))
-      expect_error(.rx$.rxMuRef(paste0("a=", type, "(tka + eta.ka, 0.5)"), lmat), NA)
-      expect_error(.rx$.rxMuRef(paste0("a=", type, "(tka + eta.ka, a)"), lmat))
-      expect_error(.rx$.rxMuRef(paste0("a=", type, "(tka + eta.ka, 4)"), lmat))
+      expect_error(.rxMuRef(paste0("a=", type, "(tka + eta.ka, a, b)"), lmat))
+      expect_error(.rxMuRef(paste0("a=", type, "(tka + eta.ka, 1, b)"), lmat))
+      expect_error(.rxMuRef(paste0("a=", type, "(tka + eta.ka, 1, b)"), lmat))
+      expect_error(.rxMuRef(paste0("a=", type, "(tka + eta.ka, 1, 2)"), lmat), NA)
+      expect_error(.rxMuRef(paste0("a=", type, "(tka + eta.ka, 2, 1)"), lmat))
+      expect_error(.rxMuRef(paste0("a=", type, "(tka + eta.ka, 0.5)"), lmat), NA)
+      expect_error(.rxMuRef(paste0("a=", type, "(tka + eta.ka, a)"), lmat))
+      expect_error(.rxMuRef(paste0("a=", type, "(tka + eta.ka, 4)"), lmat))
     }
 
     testBounded("logit")
@@ -37,8 +35,8 @@ rxTest({
   })
 
   test_that("bad mu referencing examples (throw error)", {
-    expect_error(.rx$.rxMuRef("a=theta1+theta2+theta3*wt+eta1", lmat))
-    expect_error(.rx$.rxMuRef("a=theta1+theta2*wt+theta3*wt+eta1", lmat))
+    expect_error(.rxMuRef("a=theta1+theta2+theta3*wt+eta1", lmat))
+    expect_error(.rxMuRef("a=theta1+theta2*wt+theta3*wt+eta1", lmat))
   })
 
   testEnv <- function(env, ref) {
@@ -48,34 +46,30 @@ rxTest({
     invisible()
   }
 
-  listEnv <- function(env){
+  listEnv <- function(env) {
     refNames <- c("muRefCovariateDataFrame", "muRefCovariateEmpty", "muRefCurEval", "muRefDataFrame",
                   "muRefDropParameters", "muRefExtra", "muRefExtraEmpty", "nonMuEtas")
-    setNames(lapply(refNames, function(n){
+    setNames(lapply(refNames, function(n) {
       get(n, env)
     }), refNames)
   }
 
-  messageEnv <- function(env){
+  messageEnv <- function(env) {
     message(paste0(deparse(listEnv(env)), collapse="\n"))
   }
 
   test_that("simple mu referencing", {
     lmat <- lotri({
-      ## You may label each parameter with a comment
-      tka <- 0.45 # Log Ka
-      tcl <- log(c(0, 2.7, 100)) # Log Cl
-      ## This works with interactive models
-      ## You may also label the preceding line with label("label text")
-      tv <- 3.45; label("log V")
-      ## the label("Label name") works with all models
+      tka <- 0.45
+      tcl <- log(c(0, 2.7, 100))
+      tv <- 3.45
       eta.ka ~ 0.6
       eta.cl ~ 0.3
       eta.v ~ 0.1
       add.sd <- 0.7
     })
 
-    env <- .rx$.rxMuRef(rxode2({
+    env <- .rxMuRef(rxode2({
       ka <- exp(tka + eta.ka)
       cl <- exp(tcl + eta.cl)
       v <- tv + eta.v
@@ -113,7 +107,7 @@ rxTest({
     })
 
     ## Test a duplicated eta; It shouldn't be counted as mu-referenced
-    env <- .rx$.rxMuRef(rxode2({
+    env <- .rxMuRef(rxode2({
       EmaxA <- exp(t.EmaxA + eta.emax)
       EmaxB <- exp(t.EmaxB + eta.emax)
       EmaxC <- exp(t.EmaxC + eta.emax)
@@ -134,7 +128,7 @@ rxTest({
                  muRefExtra = structure(list(parameter = character(0), extra = character(0)), class = "data.frame", row.names = integer(0)),
                  muRefExtraEmpty = c("t.EmaxA", "t.EmaxB", "t.EmaxC"), nonMuEtas = "eta.emax"))
 
-    env <- .rx$.rxMuRef(rxode2({
+    env <- .rxMuRef(rxode2({
       EmaxA <- exp(t.EmaxA + eta.emax)
       EmaxB <- exp(t.EmaxB + eta.emax)
       EmaxC <- t.EmaxC + eta.emax
@@ -155,7 +149,7 @@ rxTest({
                  muRefExtra = structure(list(parameter = character(0), extra = character(0)), class = "data.frame", row.names = integer(0)),
                  muRefExtraEmpty = c("t.EmaxA", "t.EmaxB", "t.EmaxC"), nonMuEtas = "eta.emax"))
 
-    env <- .rx$.rxMuRef(rxode2({
+    env <- .rxMuRef(rxode2({
       EmaxB <- t.EmaxB + eta.emax
       EmaxA <- exp(t.EmaxA + eta.emax)
     }), lmat)
@@ -179,20 +173,16 @@ rxTest({
   test_that("composite ode expressions", {
 
     lmat <- lotri({
-      ## You may label each parameter with a comment
-      tka <- 0.45 # Log Ka
-      tcl <- log(c(0, 2.7, 100)) # Log Cl
-      ## This works with interactive models
-      ## You may also label the preceding line with label("label text")
-      tv <- 3.45; label("log V")
-      ## the label("Label name") works with all models
+      tka <- 0.45
+      tcl <- log(c(0, 2.7, 100))
+      tv <- 3.45
       eta.ka ~ 0.6
       eta.cl ~ 0.3
       eta.v ~ 0.1
       add.sd <- 0.7
     })
 
-    env <- .rx$.rxMuRef(rxode2({
+    env <- .rxMuRef(rxode2({
       d/dt(depot) = -exp(tka + eta.ka) * depot
       d/dt(center) = exp(tka + eta.ka) * depot - exp(tcl + eta.cl)/exp(tv + eta.v) * center
       cp = center/exp(tv + eta.v)
@@ -235,20 +225,16 @@ rxTest({
   test_that("old style tka*eta(eta.ka)", {
 
     lmat <- lotri({
-      ## You may label each parameter with a comment
-      tka <- 0.45 # Log Ka
-      tcl <- log(c(0, 2.7, 100)) # Log Cl
-      ## This works with interactive models
-      ## You may also label the preceding line with label("label text")
-      tv <- 3.45; label("log V")
-      ## the label("Label name") works with all models
+      tka <- 0.45
+      tcl <- log(c(0, 2.7, 100))
+      tv <- 3.45
       eta.ka ~ 0.6
       eta.cl ~ 0.3
       eta.v ~ 0.1
       add.sd <- 0.7
     })
 
-    env <- .rx$.rxMuRef(rxode2({
+    env <- .rxMuRef(rxode2({
       ka <- tka * exp(eta.ka + 0)
       cl <- tcl * exp(eta.cl + 0)
       v <- tv * exp(eta.v + 0)
@@ -276,7 +262,7 @@ rxTest({
                                                                                                               ), class = "data.frame"), muRefExtraEmpty = NULL, nonMuEtas = c("eta.ka",
                                                                                                                                                                               "eta.cl", "eta.v")))
 
-    env <- .rx$.rxMuRef(rxode2({
+    env <- .rxMuRef(rxode2({
       ka <- tka * exp(eta.ka + 0)
       cl <- tcl * exp(eta.cl + 0)
       v <- tv * exp(eta.v + 0)
@@ -305,7 +291,7 @@ rxTest({
                                                                                                               ), class = "data.frame"), muRefExtraEmpty = "tv", nonMuEtas = c("eta.ka",
                                                                                                                                                                               "eta.cl", "eta.v")))
 
-    env <- .rx$.rxMuRef(rxode2({
+    env <- .rxMuRef(rxode2({
       ka <- tka * exp(eta.ka)
       cl <- tcl * exp(eta.cl)
       v <- tv * exp(eta.v)
@@ -332,7 +318,7 @@ rxTest({
                  muRefExtraEmpty = NULL, nonMuEtas = c("eta.ka", "eta.cl",
                                                        "eta.v")))
 
-    env <- .rx$.rxMuRef(rxode2({
+    env <- .rxMuRef(rxode2({
       ka <- tka * exp(eta.ka)
       cl <- tcl * exp(eta.cl)
       v <- tv * exp(eta.v)
@@ -366,19 +352,15 @@ rxTest({
   test_that("curEval for theta only", {
 
     lmat <- lotri({
-      ## You may label each parameter with a comment
-      tka <- 0.45 # Log Ka
-      tcl <- log(c(0, 2.7, 100)) # Log Cl
-      ## This works with interactive models
-      ## You may also label the preceding line with label("label text")
-      tv <- 3.45; label("log V")
-      ## the label("Label name") works with all models
+      tka <- 0.45
+      tcl <- log(c(0, 2.7, 100))
+      tv <- 3.45
       eta.cl ~ 0.3
       eta.v ~ 0.1
       add.sd <- 0.7
     })
 
-    env <- .rx$.rxMuRef(rxode2({
+    env <- .rxMuRef(rxode2({
       ka <- exp(tka)
       cl <- exp(tcl + eta.cl)
       v <- tv * exp(eta.v)
@@ -409,13 +391,10 @@ rxTest({
   test_that("test covariates", {
 
     lmat <- lotri({
-      ## You may label each parameter with a comment
-      tka <- 0.45 # Log Ka
-      tcl <- log(c(0, 2.7, 100)) # Log Cl
-      ## This works with interactive models
-      ## You may also label the preceding line with label("label text")
-      tv <- 3.45; label("log V")
-      tvp <- 3.45; label("log V")
+      tka <- 0.45
+      tcl <- log(c(0, 2.7, 100))
+      tv <- 3.45
+      tvp <- 3.45
       cl.wt <- 0.1
       v.wt <- 0.1
       cl.sex <- 0.1
@@ -425,14 +404,13 @@ rxTest({
       vp.wt <- 1
       vp.sex <- 1
       vp.age <- 1
-      ## the label("Label name") works with all models
       eta.ka ~ 0.6
       eta.cl ~ 0.3
       eta.v ~ 0.1
       add.sd <- 0.7
     })
 
-    env <- .rx$.rxMuRef(rxode2({
+    env <- .rxMuRef(rxode2({
       ka <- exp(tka + eta.ka)
       cl <- exp(tcl + eta.cl + log(wt2 / 70) * cl.wt + sex * cl.sex + age * cl.age + 3)
       v  <- exp(tv + eta.v + wt * v.wt + sex * v.sex + age * v.age + 2)
@@ -467,7 +445,7 @@ rxTest({
 
 
     # This one tv is used in 2 covariate references
-    env <- .rx$.rxMuRef(rxode2({
+    env <- .rxMuRef(rxode2({
       ka <- exp(tka + eta.ka)
       cl <- exp(tcl + eta.cl + log(wt2 / 70) * cl.wt + sex * cl.sex + age * cl.age + 3)
       v  <- exp(tv + eta.v + wt * v.wt + sex * v.sex + age * v.age + 2)
@@ -598,9 +576,9 @@ rxTest({
 
     one.cmt <- function() {
       ini({
-        tka <- 0.45 ; label("Ka")
-        tcl <- log(c(0, 2.7, 100)) ; label("Log Cl")
-        tv <- 3.45; label("log V")
+        tka <- 0.45
+        tcl <- log(c(0, 2.7, 100))
+        tv <- 3.45
         cl.wt <- 0
         v.wt <- 0
         eta.ka ~ 0.6
@@ -625,9 +603,9 @@ rxTest({
 
     one.cmt <- function() {
       ini({
-        tka <- 0.45 ; label("Ka")
-        tcl <- log(c(0, 2.7, 100)) ; label("Log Cl")
-        tv <- 3.45; label("log V")
+        tka <- 0.45
+        tcl <- log(c(0, 2.7, 100))
+        tv <- 3.45
         cl.wt <- 0
         v.wt <- 0
         eta.ka ~ 0.6
@@ -653,9 +631,9 @@ rxTest({
 
     one.cmt <- function() {
       ini({
-        tka <- 0.45 ; label("Ka")
-        tcl <- log(c(0, 2.7, 100)) ; label("Log Cl")
-        tv <- 3.45; label("log V")
+        tka <- 0.45
+        tcl <- log(c(0, 2.7, 100))
+        tv <- 3.45
         cl.wt <- 0
         v.wt <- 0
         eta.ka ~ 0.6
