@@ -117,5 +117,38 @@ rxTest({
 
     f <- dplyr::rename(ocmt, alag=d)
     expect_equal(f$lstExpr[[6]], quote(lag(depot) <- alag))
+
+    ocmt <- function() {
+      ini({
+        tka <- exp(0.45)
+        tcl <- exp(1)
+        tv <- exp(3.45)
+        add.sd <- 0.7
+      })
+      model({
+        ka <- tka
+        cl <- tcl
+        v <- tv
+        d/dt(depot) = -ka * depot
+        depot(0) <- 1
+        rate(depot) <- 1
+        dur(depot) <- 1
+        alag(depot) <- 1
+        d/dt(center) = ka * depot - cl / v * center
+        cp = center / v
+        cp ~ add(add.sd)
+      })
+    }
+
+    tmp <- rxRename(rxode2(ocmt), dcmt=depot)
+
+    expect_equal(tmp$lstExpr[[5]], quote(dcmt(0) <- 1))
+
+    expect_equal(tmp$lstExpr[[6]], quote(rate(dcmt) <- 1))
+    expect_equal(tmp$lstExpr[[7]], quote(dur(dcmt) <- 1))
+    expect_equal(tmp$lstExpr[[8]], quote(alag(dcmt) <- 1))
+    
+
+    
   })
 })
